@@ -36,6 +36,8 @@ extern FullScreen       *fullscreen;
 extern gint              StartInFullscreen;
 extern int               StartSlideshow;
 extern int               ViewFirstImage;
+extern int               HideSidebar;
+extern gboolean          ExitAll;
 
 
 #define MENU_ICON_SIZE 20.0
@@ -52,12 +54,17 @@ void all_windows_update_viewer_options         ();
 
 void all_windows_update_browser_options        ();
 
-void all_windows_update_editors_menu           ();
+void all_windows_notify_files_created          (GList *list);
 
 void all_windows_notify_files_deleted          (GList *list);
 
-void all_windows_notify_cat_files_deleted      (const gchar *catalog_path,
-						GList *list);
+void all_windows_notify_files_changed          (GList *list);
+
+void all_windows_notify_cat_files_added        (const char *catalog_path,
+						GList      *list);
+
+void all_windows_notify_cat_files_deleted      (const char *catalog_path,
+						GList      *list);
 
 void all_windows_notify_file_rename            (const gchar *oldname,
 						const gchar *newname);
